kenchi\.outlier\_detection package
==================================

Submodules
----------

.. toctree::

   kenchi.outlier_detection.angle_based
   kenchi.outlier_detection.base
   kenchi.outlier_detection.clustering_based
   kenchi.outlier_detection.distance_based
   kenchi.outlier_detection.reconstruction_based
   kenchi.outlier_detection.statistical

Module contents
---------------

.. automodule:: kenchi.outlier_detection
    :members:
    :undoc-members:
    :show-inheritance:
